Cheshire3 Object Model - TokenMerger
====================================

.. _objects-tokenMerger-api:

API
---

.. autoclass:: cheshire3.baseObjects.TokenMerger
   :members:


.. _objects-tokenMerger-implementations:

Implementations
---------------

The following implementations are included in the distribution by default:

.. autoclass:: cheshire3.tokenMerger.SimpleTokenMerger

.. autoclass:: cheshire3.tokenMerger.ProximityTokenMerger

.. autoclass:: cheshire3.tokenMerger.OffsetProximityTokenMerger

.. autoclass:: cheshire3.tokenMerger.RangeTokenMerger

.. autoclass:: cheshire3.tokenMerger.SequenceRangeTokenMerger

.. autoclass:: cheshire3.tokenMerger.MinMaxRangeTokenMerger

.. autoclass:: cheshire3.tokenMerger.NGramTokenMerger

.. autoclass:: cheshire3.tokenMerger.ReconstructTokenMerger

.. autoclass:: cheshire3.tokenMerger.PhraseTokenMerger
